OC.L10N.register(
    "settings",
    {
    "Private" : "Частен",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Видим само за хора, съчетани чрез интегриране на телефонен номер чрез Talk на мобилен телефон",
    "Local" : "Локално",
    "Only visible to people on this instance and guests" : "Вижда се само за хора в този екземпляр и гости",
    "Federated" : "Федериран",
    "Only synchronize to trusted servers" : "Синхронизиране само с доверени сървъри",
    "Published" : "Публикувано",
    "Synchronize to trusted servers and the global and public address book" : "Синхронизиране с доверени сървъри и с глобалната и публичната адресна книга",
    "Verify" : "Потвърждаване",
    "Verifying …" : "Потвърждаване...",
    "Unable to change password" : "Неуспешна смяна на паролата.",
    "Very weak password" : "Много проста парола",
    "Weak password" : "Проста парола",
    "So-so password" : "Не особено добра парола",
    "Good password" : "Добра парола",
    "Strong password" : "Сложна парола",
    "Groups" : "Групи",
    "Group list is empty" : "Списъкът с групи е празен",
    "Unable to retrieve the group list" : "Не може да се извлече списъкът с групи",
    "{actor} added you to group {group}" : "{actor} ви добави към група {group}",
    "You added {user} to group {group}" : "Добавихте {user} към групата {group}",
    "{actor} added {user} to group {group}" : "{actor} добави {user} към група {group}",
    "An administrator added you to group {group}" : "Администратор ви добави към група {group}",
    "An administrator added {user} to group {group}" : "Администратор добави {user} към група {group}",
    "{actor} removed you from group {group}" : "{actor} ви премахна от група {group}",
    "You removed {user} from group {group}" : "Премахнахте {user} от група {group}",
    "{actor} removed {user} from group {group}" : "{actor} премахна {user} от група {group}",
    "An administrator removed you from group {group}" : "Администратор ви премахна от група {group}",
    "An administrator removed {user} from group {group}" : "Администратор премахна {user} от група {group}",
    "Your <strong>group memberships</strong> were modified" : "Вашите <strong>членства в групи</strong> бяха модифицирани",
    "{actor} changed your password" : "{actor} промени паролата ви",
    "You changed your password" : "Променихте паролата си",
    "Your password was reset by an administrator" : "Паролата ви е променена от администратора",
    "Your password was reset" : "Вашата парола беше възстановена",
    "{actor} changed your email address" : "{actor} промени имейл адреса ви",
    "You changed your email address" : "Променихте имейл адреса си",
    "Your email address was changed by an administrator" : "Имейл адреса ви е променена от администратора",
    "You created an app password for a session named \"{token}\"" : "Създали сте парола за приложение за сесия с име „{token}“.",
    "An administrator created an app password for a session named \"{token}\"" : "Администратор създаде парола за приложение за сесия с име „{token}“",
    "You deleted app password \"{token}\"" : "Изтрихте парола за приложение „{token}“",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Преименувахте паролата за приложение „{token}“ на „{newToken}“",
    "You granted filesystem access to app password \"{token}\"" : "Предоставихте достъп на файлова система до паролата за приложение „{token}“",
    "You revoked filesystem access from app password \"{token}\"" : "Отменихте достъп на файлова система до парола за приложение „{token}“",
    "Security" : "Сигурност",
    "You successfully logged in using two-factor authentication (%1$s)" : "Влязохте успешно с помощта на двустепенно удостоверяване (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Неуспешен опит за влизане с двустепенно удостоверяване (%1$s)",
    "Remote wipe was started on %1$s" : "Отдалеченото изтриване беше стартирано на %1$s",
    "Remote wipe has finished on %1$s" : "Отдалеченото изтриване приключи на %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Вашата <strong>парола</strong> или <strong>имейл адрес</strong> е променен",
    "Apps" : "Приложения",
    "Could not remove app." : "Приложението не можа да се премахне.",
    "Could not update app." : "Приложението не можа да се актуализира.",
    "Wrong password" : "Грешна парола",
    "Unable to change personal password" : "Неуспешна промяна на личната парола",
    "Saved" : "Запаметяване",
    "No user supplied" : "Липсва потребител",
    "Unable to change password. Password too long." : "Неуспешна промяна на паролата. Паролата е твърде дълга.",
    "Authentication error" : "Възникна проблем с удостоверяването",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Моля, да предоставите администраторска парола за възстановяване; в противен случай всички потребителски данни ще бъдат загубени.",
    "Wrong admin recovery password. Please check the password and try again." : "Грешна администраторска парола за възстановяване. Моля, проверете паролата и опитайте отново.",
    "Backend does not support password change, but the user's encryption key was updated." : "Сървърът не поддържа промяна на паролата, но ключът за криптиране на потребителя беше актуализиран.",
    "installing and updating apps via the App Store or Federated Cloud Sharing" : "инсталиране и актуализиране на приложения чрез App Store или Federated Cloud Sharing/Федерирано споделяне в облак/",
    "Federated Cloud Sharing" : "Федерирано споделяне в облак",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL използва остаряла %1$s  версия на (%2$s). Моля, актуализирайте операционната си система или функции като %3$s, няма да работят надеждно.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "Не можа да се определи дали TLS версията на cURL е остаряла или не, защото възникна грешка по време на HTTPS заявката срещу https://nextcloud.com. Моля, проверете регистрационния файл /журнал/ на  Nextcloud за повече подробности.",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "PHP OPcache модулът не е зареден. За по-добра производителност се препоръчва да го заредите във вашата PHP инсталация.",
    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "OPcache е деактивиран. За по-добра производителност се препоръчва да се приложи <code>opcache.enable=1</code> към вашата PHP конфигурация.",
    "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcache е конфигуриран за премахване на кодови коментари. С активиран OPcache, <code>opcache.save_comments=1</code> трябва да бъде настроен за Nextcloud, за да функционира.",
    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud няма право да използва OPcache API. При активиран OPcache е силно препоръчително да включите всички директории Nextcloud с <code>opcache.restrict_api</code> или деактивирайте тази настройка, за да деактивирате ограниченията на OPcache API, за да предотвратите грешки по време на надстройки на ядрото или приложението на Nextcloud.",
    "Nextcloud is not allowed to use the OPcache API. It is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud няма право да използва OPcache API. Силно препоръчително е да включите всички директории Nextcloud с <code>opcache.restrict_api</code> или деактивирайте тази настройка, за да деактивирате ограниченията на OPcache API, за да предотвратите грешки по време на надстройки на ядрото или приложението на Nextcloud.",
    "The shared memory based OPcache is disabled. For better performance, it is recommended to apply <code>opcache.file_cache_only=0</code> to your PHP configuration and use the file cache as second level cache only." : "Базираният на споделена памет OPcache е деактивиран. За по-добра производителност се препоръчва да приложите <code>opcache.file_cache_only=0</code> към конфигурацията на PHP и да използвате файловия кеш само като кеш от второ ниво.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "Максималният брой OPcache ключове почти е надвишен. За да се гарантира, че всички скриптове могат да се задържат в кеш, се препоръчва да се приложи <code>opcache.max_accelerated_files</code> към вашата PHP конфигурация със стойност, по-висока от <code>%s</code>.",
    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "Буферът на OPcache е почти пълен. За да се гарантира, че всички скриптове могат да се задържат в кеш, се препоръчва да се приложи <code>opcache.memory_consumption</code> към вашата PHP конфигурация със стойност, по-висока от <code>%s</code>.",
    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "Буферът за интернирани низове в OPcache е почти пълен. За да се гарантира, че повтарящите се низове могат да бъдат ефективно кеширани, се препоръчва да се приложи <code>opcache.interned_strings_buffer</code> към вашата PHP конфигурация със стойност, по-висока от<code>%s</code>.",
    "Administrator documentation" : "Документация за администратори",
    "User documentation" : "Документация за потребители",
    "Invalid SMTP password." : "Невалидна SMTP парола.",
    "Email setting test" : "Тест за настройка на имейл",
    "Well done, %s!" : "Браво, %s!",
    "If you received this email, the email configuration seems to be correct." : "Ако сте получили този имейл, конфигурацията на имейла изглежда е правилна.",
    "Email could not be sent. Check your mail server log" : "Ймеила не се изпрати.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Възникна проблем при изпращането на имейла. Моля, провери настройките.  (Грешка: %s)",
    "You need to set your user email before being able to send test emails. Go to %s for that." : "Трябва да зададете свои потребителски имейл, преди да можете да изпращате тестови имейли. За това отидете на %s.",
    "Users" : "Потребители",
    "Invalid user" : "Невалиден потребител",
    "Invalid mail address" : "невалиден адрес на електронна поща",
    "Settings saved" : "Настройките са запазени",
    "Unable to change full name" : "Неуспешна промяна на име.",
    "Unable to change email address" : "Неуспешна промяна на адрес на електронна поща",
    "Unable to set invalid phone number" : "Не може да се зададе невалиден телефонен номер",
    "Unable to set invalid website" : "Не може да се зададе невалиден уеб сайт",
    "Some account data was invalid" : "Някои данни за профил са невалидни",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "За да потвърдите вашият профил в Twitter, публикувайте следния туит в Twitter (моля, не забравяйте да го публикувате без прекъсвания на редове):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "За да потвърдите вашият уеб сайт, съхранете следното съдържание във вашата уеб директория на адрес '.well-known/CloudIdVerificationCode.txt' (моля, уверете се, че пълният текст е на един ред):",
    "%1$s changed your password on %2$s." : "%1$s промени вашата парола за %2$s.",
    "Your password on %s was changed." : "Вашата парола за %s беше променена.",
    "Your password on %s was reset by an administrator." : "Вашата парола на %s беше рестартирана от администратор.",
    "Your password on %s was reset." : "Вашата парола за %s беше възстановена.",
    "Password for %1$s changed on %2$s" : "Паролата за %1$s е променена на %2$s",
    "Password changed for %s" : "Паролата на %s е променена",
    "If you did not request this, please contact an administrator." : "Моля, свържете се с администратор ако промяната не е извършена от вас.",
    "Your email address on %s was changed." : "Вашият имейл адрес, беше променен на %s .",
    "Your email address on %s was changed by an administrator." : "На %s, вашият имейл адрес беше променен от администратор.",
    "Email address for %1$s changed on %2$s" : "Имейл адрес за %1$s е променен на %2$s",
    "Email address changed for %s" : "Имейл адрес е променен за %s",
    "The new email address is %s" : "Новият имейл адрес е %s",
    "Your %s account was created" : "Вашия %s профил бе създаден",
    "Welcome aboard" : "Добре дошли",
    "Welcome aboard %s" : "Добре дошли %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Добре дошли във вашия %s акаунт, можете да добавяте, защитавате и споделяте своите данни.",
    "Your username is: %s" : "Потребителско име: %s",
    "Set your password" : "Задайте парола",
    "Go to %s" : "Отидете на %s",
    "Install Client" : "Инсталиране на клиента",
    "Logged in user must be a subadmin" : "Влезлият потребител трябва да е подадминистратор",
    "Settings" : "Настройки",
    "Personal" : "Лични",
    "Administration" : "Административни",
    "Additional settings" : "Допълнителни настройки",
    "Administration privileges" : "Административни привилегии",
    "Groupware" : "Групов софтуер",
    "Overview" : "Преглед",
    "Basic settings" : "Основни настройки",
    "Sharing" : "Споделяне",
    "Availability" : "Наличност",
    "Calendar" : "Kалендар",
    "Personal info" : "Лични данни",
    "Mobile & desktop" : "Мобилни и настолни",
    "Email server" : "Имейл сървър",
    "Security & setup warnings" : "Предупреждения за сигурността и настройките",
    "Background jobs" : "Фонови процеси",
    "Create" : "Създай",
    "Change" : "Промени",
    "Delete" : "Изтриване",
    "Reshare" : "Повторно споделяне",
    "Unlimited" : "Неограничено",
    "Verifying" : "Потвърждаване",
    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Предстои фонова работа, която проверява за импортирани от потребителя SSL сертификати. Моля, проверете отново по-късно.",
    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Има някои импортирани от потребителя SSL сертификати, които вече не се използват с Nextcloud 21. Те ​​могат да бъдат импортирани в командния ред, чрез командата \"occ security:certificates:import\". Техните пътища в директорията с данни са показани по-долу.",
    "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "Открит е невалиден UUID на потребители или групи на LDAP. Моля, прегледайте настройките си за \"Override UUID detection\"/ откриване на отмяна на UUID/, в експертната част на LDAP конфигурацията и използвайте \"occ ldap:update-uuid\", за да ги актуализирате.",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Старият формат за криптиране от страна на сървъра е активиран. Препоръчваме да го деактивирате.",
    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "Използва се версия на MariaDB „%s “. Nextcloud 21 и по-новите версии вече няма да поддържат тази версия и се изисква MariaDB 10.2 или по-нова версия.",
    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "Използва се версия на MySQL „ %s“. Nextcloud 21 и по-новите версии вече няма да поддържат тази версия и се изискват MySQL 8.0 или MariaDB 10.2, или по-нова версия.",
    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "Използва се PostgreSQL версия „%s “. Nextcloud 21 и по-новите версии вече няма да поддържат тази версия и се изисква PostgreSQL 9.6 или по-нова версия.",
    "Profile information" : "Информация за профила",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Снимка на потребителския профил, пълно име, имейл, телефонен номер, адрес, уеб сайт, Twitter, организация, роля, заглавие, биография и дали вашият профил е активиран",
    "Nextcloud settings" : "Nextcloud настройки",
    "Here you can decide which group can access certain sections of the administration settings." : "Тук можете да решите коя група има достъп до определени секции от настройките за администриране.",
    "None" : "Няма",
    "Unable to modify setting" : "Не може да се промени настройката",
    "Two-Factor Authentication" : "Двустепенно удостоверяване",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Двустепенното удостоверяване може да бъде наложено за всички потребители и специфични групи. Ако нямат конфигуриран двустепенен доставчик, те няма да могат да влязат в системата.",
    "Enforce two-factor authentication" : "Прилагане на двустепенно удостоверяване",
    "Limit to groups" : "Ограничен достъп",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Прилагането на двустепенно удостоверяване, може да бъде зададено само за определени групи.",
    "Two-factor authentication is enforced for all members of the following groups." : "Двустепенно удостоверяване се прилага за всички членове на следните групи.",
    "Enforced groups" : "Наложени групи",
    "Two-factor authentication is not enforced for members of the following groups." : "Двустепенно удостоверяване не се прилага за членове на следните групи.",
    "Excluded groups" : "Изключени групи",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Когато групите са избрани/изключени, те използват следната логика, за да определят дали даден потребител има наложена 2FA: Ако не са избрани групи, 2FA се активира за всички, с изключение на членовете на изключените групи. Ако са избрани групи, 2FA се активира за всички техни членове. Ако потребител е едновременно в избрана и изключена група, избраното има предимство и 2FA се прилага.",
    "Save changes" : "Запиши промените",
    "All" : "Всички",
    "Limit app usage to groups" : "Ограничаване използването на приложението от групи",
    "No results" : "Няма резултати",
    "Update to {version}" : "Актуализирай до {version}",
    "Remove" : "Премахване",
    "Disable" : "Изключване",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Това приложение няма присвоена минимална версия на Nextcloud. В бъдеще това ще бъде грешка.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Това приложение няма зададена максимална версия на Nextcloud. В бъдеще това ще бъде грешка.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Приложението не може да бъде инсталирано, защото следните зависимости не са удовлетворени:",
    "View in store" : "Страница в магазина",
    "Visit website" : "Уеб страницата",
    "Report a bug" : "Докладване на грешка",
    "Admin documentation" : "Документация за администратори",
    "Developer documentation" : "Документация за разработчици",
    "This app is supported via your current Nextcloud subscription." : "Това приложение се поддържа чрез текущия ви абонамент за Nextcloud.",
    "Supported" : "Поддържан",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Представените приложения са разработени от и в рамките на общността. Те предлагат централна функционалност и са готови за производствена употреба.",
    "Featured" : "Препоръчани",
    "Update to {update}" : "Актуализирай до {update}",
    "All apps are up-to-date." : "Всички приложения са актуални.",
    "Results from other categories" : "Резултати от други категории",
    "No apps found for your version" : "Няма намерени приложения за версията, която ползвате",
    "Disable all" : "Изключи всички",
    "Enable all" : "Активирай всички",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n приложения имат налична актуализация ","%n приложения имат налична актуализация"],
    "_Update_::_Update all_" : ["Актуализиране на всички","Актуализиране на всички"],
    "Marked for remote wipe" : "Маркирано за отдалечено изтриване",
    "Device settings" : "Настройки за устройството",
    "Allow filesystem access" : "Разрешен достъп до файловете",
    "Rename" : "Преименувай",
    "Revoke" : "Отнемане",
    "Wipe device" : "Изтрий устройството",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Отмяната на този маркер може да попречи на изтриването на вашето устройство, ако то все още не е започнало изтриването.",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome за Android",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "{productName} iOS app" : "{productName} приложение за iOS",
    "{productName} Android app" : "{productName} приложение за Android",
    "{productName} Talk for iOS" : "{productName} Talk за iOS",
    "{productName} Talk for Android" : "{productName} Talk за Android",
    "Sync client - {os}" : "Клиент за синхронизиране - {os}",
    "This session" : "Текущата сесия",
    "Device" : "Устройство",
    "Last activity" : "Последна активност",
    "Devices & sessions" : "Устройства и сесии",
    "Web, desktop and mobile clients currently logged in to your account." : "Уеб, настолни и мобилни клиенти, които в момента са вписани чрез вашия акаунт.",
    "Do you really want to wipe your data from this device?" : "Наистина ли желаете да изтриете цялата информация от това устройство?",
    "Confirm wipe" : "Потвърди изтриването",
    "Error while creating device token" : "Грешка при създаването на токен на устройството",
    "Error while updating device token scope" : "Грешка при актуализиране на обхвата на токена на устройството",
    "Error while updating device token name" : "Грешка при актуализиране на името на токена на устройството",
    "Error while deleting the token" : "Грешка при изтриването на токен",
    "Error while wiping the device with the token" : "Грешка при изтриване на устройството с токена",
    "App name" : "Име на приложението",
    "Create new app password" : "Създай парола за приложението",
    "Use the credentials below to configure your app or device." : "Ползвайте данните по-долу за да настроите вашето приложение или устройство.",
    "For security reasons this password will only be shown once." : "Тази парола ще бъде показана само веднъж.",
    "Username" : "Потребител",
    "Password" : "Парола",
    "Done" : "Готово",
    "Show QR code for mobile apps" : "Показване на QR код за мобилни приложения",
    "Copied!" : "Копирано!",
    "Copy" : "Копиране",
    "Could not copy app password. Please copy it manually." : "Не можа да се копира паролата за приложение. Моля, копирайте я ръчно.",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "За да работи правилно сървърът, е важно да конфигурирате правилно фоновите задачи. Препоръчителната настройка е Cron. Моля, вижте документацията за повече информация.",
    "Last job execution ran {time}. Something seems wrong." : "Изпълнението на последното задание се изпълни {time}. Нещо не е наред.",
    "Last job ran {relativeTime}." : "Последната задача се изпълни {relativeTime}.",
    "Background job did not run yet!" : "Фоновата задача все още не е стартирана!",
    "AJAX" : "AJAX",
    "Execute one task with each page loaded. Use case: Single user instance." : "Изпълняване на една задача с всяка заредена страница. Случай на употреба: Екземпляр за един потребител.",
    "Webcron" : "Webcron",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php е регистриран в услуга на webcron за извикване на cron.php на всеки 5 минути през HTTP. Случай на употреба: Много малък екземпляр (1–5 потребители в зависимост от употребата).",
    "Cron (Recommended)" : "Cron (препоръчително)",
    "Use system cron service to call the cron.php file every 5 minutes." : "Използвайте системната услуга cron, за да извикате файла cron.php на всеки 5 минути.",
    "The cron.php needs to be executed by the system user \"{user}\"." : "Cron.php трябва да се изпълни от системният потребител \"{user}\".",
    "Unable to update background job mode" : "Не може да се актуализира фонов режим на работа",
    "Profile" : "Профил",
    "Enable or disable profile by default for new users." : "Активиране или деактивиране на профила по подразбиране за нови потребители.",
    "Enable" : "Включване",
    "Unable to update profile default setting" : "Не може да се актуализира настройката по подразбиране на профила",
    "Server-side encryption" : "Сървърно криптиране",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Криптирането от страна на сървъра, прави възможно криптирането на файлове, които се качват на този сървър. Това идва с ограничения като намаляване на производителността, така че го активирайте, само ако е необходимо. ",
    "Enable server-side encryption" : "Активиране на криптирането от страна на сървъра",
    "Please read carefully before activating server-side encryption:" : "Моля, прочетете внимателно, преди да активирате криптирането от страна на сървъра:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "След като криптирането е активирано, всички файлове, качени на сървъра от този момент нататък, ще бъдат криптирани в състояние на покой на сървъра. Ще бъде възможно да деактивирате криптирането на по-късна дата, само ако активният модул за криптиране поддържа тази функция и всички предварителни условия (например задаване на ключ за възстановяване) са изпълнени.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Само криптирането не гарантира сигурността на системата. Моля, вижте документацията за повече информация относно това как работи приложението за криптиране и поддържаните случаи на употреба.",
    "Be aware that encryption always increases the file size." : "Имайте предвид, че криптирането винаги увеличава размера на файла.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Добре е винаги да създавате редовни резервни копия на вашите данни, в случай на криптиране не забравяйте да архивирате ключовете за криптиране заедно с вашите данни.",
    "This is the final warning: Do you really want to enable encryption?" : "Това е последно предупреждение: Наистина ли искате да активирате криптирането?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Няма зареден модул за криптиране, моля, активирайте модул за криптиране в менюто на приложението.",
    "Select default encryption module:" : "Избор на модул за криптиране по подразбиране:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Трябва да мигрирате ключовете си за криптиране от старото криптиране (ownCloud <= 8.0) към новото. Моля, активирайте „Модул за криптиране по подразбиране“ и изпълнете {command}",
    "Unable to update server side encryption config" : "Не може да се актуализира конфигурацията за криптиране от страна на сървъра",
    "Rename group" : "Преименуване на група",
    "Remove group" : "Премахване на групата",
    "You are about to remove the group {group}. The users will NOT be deleted." : "На път сте да премахнете групата {group}. Потребителите НЯМА да бъдат изтрити.",
    "Please confirm the group removal " : "Моля, потвърдете премахването на групата",
    "Current password" : "Текуща парола",
    "New password" : "Нова парола",
    "Change password" : "Промени паролата",
    "Your profile information" : "Информация за вашия профил",
    "Your profile picture" : "Вашата профилна снимка",
    "Upload profile picture" : "Качване на профилна снимка",
    "Choose profile picture from Files" : "Избор на профилна снимка от Файлове",
    "Remove profile picture" : "Премахване на профилна снимка",
    "The file must be a PNG or JPG" : "Файлът трябва да е във формат PNG или JPG",
    "Picture provided by original account" : "Снимката е предоставена от оригиналния профил",
    "Cancel" : "Отказ",
    "Set as profile picture" : "Задаване като профилна снимка",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Моля, имайте предвид, че може да отнеме до 24 часа, докато вашата профилна снимка бъде актуализирана навсякъде.",
    "Choose your profile picture" : "Избор на профилна снимка",
    "Please select a valid png or jpg file" : "Моля, изберете валиден png или jpg файл",
    "Error setting profile picture" : "Грешка при задаване на профилна снимка",
    "Error cropping profile picture" : "Грешка при изрязване на профилна снимка",
    "Error saving profile picture" : "Грешка при записване на профилната снимка",
    "Error removing profile picture" : "Грешка при премахване на профилна снимка",
    "Your biography" : "Вашата биография",
    "Details" : "Подробности",
    "You are a member of the following groups:" : "Членувате в следните групи:",
    "You are using <strong>{usage}</strong>" : "Използвате <strong>{usage}</strong>",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Използвате <strong>{usage}</strong> от <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
    "Your full name" : "Вашето пълно име",
    "Email options" : "Опции за имейл",
    "Primary email for password reset and notifications" : "Основен имейл за възстановяване на парола и известия",
    "Remove primary email" : "Премахване на основния имейл",
    "Delete email" : "Изтриване на имейл",
    "Unset as primary email" : "Премахване на настройка като основен имейл",
    "This address is not confirmed" : "Този адрес не е потвърден",
    "Set as primary email" : "Задаване като основен имейл",
    "Your email address" : "Вашият имейл адрес",
    "Additional email address {index}" : "Допълнителен имейл адрес {index}",
    "Unable to delete primary email address" : "Не може да се изтрие основният имейл адрес",
    "Unable to update primary email address" : "Основният имейл адрес не може да се актуализира",
    "Unable to add additional email address" : "Не може да се добави допълнителен имейл адрес",
    "Unable to update additional email address" : "Не може да се актуализира допълнителен имейл адрес",
    "Unable to delete additional email address" : "Не може да се изтрие допълнителен имейл адрес",
    "No email address set" : "Не е въведен имейл адрес",
    "Additional emails" : "Допълнителни имейли",
    "Your handle" : "Вашият манипулатор",
    "Your headline" : "Вашето заглавие",
    "Language" : "Език",
    "Help translate" : "Помогнете с превода",
    "Unable to update language" : "Езикът не може да се актуализира",
    "No language set" : "Няма зададен език",
    "Locale" : "Локален/Местен/",
    "Week starts on {firstDayOfWeek}" : "Седмицата започва на {firstDayOfWeek}",
    "Unable to update locale" : "Не може да се актуализира езиково-географската променлива",
    "No locale set" : "Не е зададена езиково-географска променлива",
    "Your organisation" : "Вашата организация",
    "Your phone number" : "Вашият тел. номер",
    "Edit your Profile visibility" : "Редактиране на видимостта на вашия профил",
    "Enable Profile" : "Активиране на профил",
    "Unable to update profile enabled state" : "Не може да се актуализира активирано състояние на профил",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "По-рестриктивна настройка за видимост или обхват се спазва във вашия профил. Например, ако видимостта е зададена на „Показване на всички“ и обхватът е настроен на „Частен“, „Частен“ се зачита.",
    "Unable to update visibility of {displayId}" : "Не може да се актуализира видимостта на {displayId}",
    "Your role" : "Вашата роля",
    "Your Twitter handle" : "Вашият Twitter манипулатор",
    "Your website" : "Вашата уеб страница",
    "No {property} set" : "Не е зададено {property}",
    "Unable to update {property}" : "Не може да се актуализира {property}",
    "Change scope level of {property}, current scope is {scope}" : "Променете нивото на обхват на {property}, текущият обхват е {scope}",
    "Unable to update federation scope of the primary {property}" : "Не може да се актуализира обхватът на обединяване на основното {property}",
    "Unable to update federation scope of additional {property}" : "Не може да се актуализира обхватът на обединяване на допълнителното {property}",
    "Add additional email" : "Добавяне на допълнителен имейл",
    "Add" : "Добави",
    "Default language" : "Стандартен език",
    "Common languages" : "Познати езици",
    "Other languages" : "Други езици",
    "Password change is disabled because the master key is disabled" : "Промяната на паролата е деактивирана, защото главният ключ е деактивиран",
    "New user" : "Нов потребител",
    "Display name" : "Вписване като",
    "Email" : "Имейл",
    "Quota" : "Квота",
    "Total rows summary" : "Обобщение на общия брой редове",
    "Avatar" : "Аватар",
    "Group admin for" : "Групов администратор за",
    "User backend" : "Потребителски сървър",
    "Storage location" : "Дисково пространство",
    "Last login" : "Последно вписване",
    "Add new password" : "Въведете новата парола",
    "You do not have permissions to see the details of this user" : "Нямате права да виждате подробности за този потребител",
    "Add new email address" : "Смени адреса на елетронната поща",
    "Add user to group" : "Добавяне на потребител към група",
    "Set user as admin for" : "Задаване на потребителя като администратор за",
    "Select user quota" : "Изберете потребителска квота",
    "{size} used" : "{size} използвани",
    "Delete user" : "Изтриване",
    "Wipe all devices" : "Изтрии всички устройства",
    "Disable user" : "Деактивирай",
    "Enable user" : "Активиране",
    "Resend welcome email" : "Повторно изпращане на имейл за добре дошъл ",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "В случай на изгубено устройство или излизане от организацията, това може отдалечено да изтрие данните на Nextcloud от всички устройства, свързани с {userid}. Работи, само ако устройствата са свързани към интернет.",
    "Remote wipe of devices" : "Отдалечено изтриване на устройства",
    "Wipe {userid}'s devices" : "Изтриване на устройствата на {userid}",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Напълно изтриване на профил на {userid}, включително всички негови лични файлове, данни от приложения и т.н.",
    "Account deletion" : "Изтриване на профил",
    "Delete {userid}'s account" : "Изтриване на профил на {userid}",
    "Welcome mail sent!" : "Изпратена е поща за добре дошли!",
    "Toggle user actions menu" : "Превключване на менюто за действия на потребител",
    "Edit" : "Редактиране",
    "Show user backend" : "Показване на потребителския сървър",
    "Show storage path" : "Показване на пътя за хранилище",
    "Show last login" : "Показвай последното вписване",
    "Send email" : "Изпрати имейл",
    "Defaults" : "Стойности по подразбиране",
    "Default quota" : "Стандартна квота",
    "Select default quota" : "Изберете стандартна квота",
    "Passwordless authentication requires a secure connection." : "Удостоверяване без парола изисква сигурна връзка.",
    "Add WebAuthn device" : "Добавяне на WebAuthn устройство",
    "Please authorize your WebAuthn device." : "Моля, да упълномощите вашето WebAuthn устройство.",
    "Name your device" : "Име на устройството",
    "Adding your device …" : "Вашето устройство се добавя …",
    "Server error while trying to add WebAuthn device" : "Грешка в сървъра при опит за добавяне на WebAuthn устройство",
    "Server error while trying to complete WebAuthn device registration" : "Грешка в сървъра при опит за завършване на регистрация на WebAuthn устройство ",
    "Unnamed device" : "Устройство без име",
    "Passwordless Authentication" : "Удостоверяване без парола",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Настройте вашият профил за удостоверяване без парола, следвайки стандарта FIDO2.",
    "No devices configured." : "Няма конфигурирани устройства.",
    "The following devices are configured for your account:" : "Следните устройства са конфигурирани за вашия профил:",
    "Your browser does not support WebAuthn." : "Вашият браузър не поддържа WebAuthn.",
    "Your apps" : "Вашите приложения",
    "{license}-licensed" : "{license}-лицензиран",
    "Changelog" : "Списък на промените",
    "by {author}\n{license}" : "от {author}\n{license}",
    "Enter group name" : "Въведете име на групата",
    "Add group" : "Нова група",
    "Active users" : "Активни потребители",
    "Admins" : "Администратори",
    "Disabled users" : "Деактивирани потребители",
    "Not saved" : "Не е запазено",
    "Sending…" : "Изпращане...",
    "Email sent" : "Имейлът е изпратен",
    "Location" : "Местоположение",
    "Profile picture" : "Снимка за профила",
    "About" : "Относно",
    "Full name" : "Име",
    "Additional email" : "Допълнителен имейл",
    "Headline" : "Заглавие",
    "Organisation" : "Организация",
    "Phone number" : "Тел. номер",
    "Role" : "Роля",
    "Twitter" : "Twitter",
    "Fediverse (e.g. Mastodon)" : "Fediverse (напр. Mastodon)",
    "Website" : "Уеб страница",
    "Profile visibility" : "Видимост на профил",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Не е налично, тъй като това свойство е нужно за основна функционалност, включително споделяне на файлове и покани в календар",
    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Не е налично, тъй като федерирането е деактивирано за вашия профил, свържете се с вашия системен администратор, ако имате въпроси.",
    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Не е налично, тъй като публикуването на специфични потребителски данни на сървъра за търсене не е разрешено, свържете се с вашия системен администратор, ако имате въпроси",
    "Active apps" : "Включени приложения",
    "Disabled apps" : "Изключени приложения",
    "Updates" : "Актуализации",
    "App bundles" : "Пакети с приложения",
    "Featured apps" : "Представени приложения",
    "Show to everyone" : "Показване на всички",
    "Show to logged in users only" : "Показване само на влезли потребители",
    "Hide" : "Скриване",
    "Download and enable" : "Сваляне и включване",
    "Enable untested app" : "Включване (нетествано приложение)",
    "The app will be downloaded from the App Store" : "Приложението ще бъде изтеглено от App Store",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Приложението не е маркирано като съвместимо с вашата версия на Nextcloud. Можете да инсталирате приложението, но е вероятно да не работи безпроблемно.",
    "Never" : "Никога",
    "An error occurred during the request. Unable to proceed." : "Възникна грешка по време на заявката. Не може да се продължи.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Приложението е активирано, но трябва да бъде актуализирано. Ще бъдете пренасочени към страницата за актуализация след 5 секунди.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Грешка: Това приложение не може да бъде активирано, защото прави сървъра нестабилен",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Имаше твърде много заявки от вашата мрежа. Опитайте отново по-късно или се свържете с вашия администратор, ако това е грешка.",
    "Documentation" : "Документация",
    "Forum" : "Форум",
    "Login" : "Вписване",
    "SSL" : "SSL",
    "Open documentation" : "Отвори документацията",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "След като настроите сървъра Nextcloud ще може да изпраща имейли за възстановяване на забравени пароли и известия.",
    "Send mode" : "Режим на изпращане",
    "Encryption" : "Криптиране",
    "Sendmail mode" : "Режим на изпращане на поща",
    "From address" : "От адрес",
    "Server address" : "Адрес на сървъра",
    "Port" : "Порт",
    "Authentication" : "Удостоверяване",
    "Authentication required" : "Нужно е удостоверяване",
    "Credentials" : "Потребител и парола",
    "SMTP Username" : "SMTP потребител",
    "SMTP Password" : "SMTP парола",
    "Save" : "Запазване",
    "Test and verify email settings" : "Тествайте и потвърждаване на настройките на имейла",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Важно е, от гледна точка на сигурност и производителност, всичко да бъде настроено коректно. За тази цел са създадени автоматични проверки. Прегледайте връзките, към документацията (по-долу), за допълнителна информация.",
    "All checks passed." : "Всички проверки са преминати.",
    "There are some errors regarding your setup." : "Открити са грешки, в инсталацията на Nextcloud.",
    "There are some warnings regarding your setup." : "Предупреждения относно текущата инсталация.",
    "Checking for system and security issues." : "Проверка за проблеми със системата и сигурността.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Прегледайте  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">ръководството за инсталиране ↗</a>, и проверете  <a href=\"%2$s\">журналите</a>за предупреждения и грешки. ",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Проверете сигурността на Nextcloud <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">като заявите сканиране ↗</a>.",
    "Version" : "Версия",
    "You need to enable the File sharing App." : "Трябва да активирате приложението за споделяне на файлове.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Като администратор можете да прецизирате поведението на споделяне. Моля, вижте документацията за повече информация.",
    "Allow apps to use the Share API" : "Разреши приложенията да използват Share API",
    "Set default expiration date for shares" : "Задай дата за изтичане по подразбиране за споделянията",
    "Expire after" : "Изтича след",
    "day(s)" : "ден(и)",
    "Enforce expiration date" : "Изисквай срок на валидност",
    "Set default expiration date for shares to other servers" : "Задайте дата на изтичане по подразбиране за споделяния към други сървъри",
    "Allow users to share via link and emails" : "Позволете на потребителите да споделят чрез връзка и имейли",
    "Allow public uploads" : "Разреши общодостъпно качване",
    "Always ask for a password" : "Винаги искайте парола",
    "Enforce password protection" : "Изискай защита с парола",
    "Exclude groups from password requirements:" : "Изключване на групит от изискванията за парола:",
    "Set default expiration date" : "Задайте дата на изтичане по подразбиране",
    "Exclude groups from creating link shares:" : "Изключване на групи от създаване на споделяния на връзки:",
    "Allow resharing" : "Може да споделя повторно",
    "Allow sharing with groups" : "Разрешаване на споделяне с групи",
    "Restrict users to only share with users in their groups" : "Ограничи потребителите, така че да могат да споделят само с други потребители в своите групи.",
    "Exclude groups from sharing" : "Забрани групи да споделят",
    "These groups will still be able to receive shares, but not to initiate them." : "Тези групи ще могат да получават споделения, но няма да могат самите те да споделят.",
    "Allow username autocompletion to users based on phone number integration" : "Разрешаване на автоматично довършване на име на потребител на потребители въз основа на интегриране на телефонен номер",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Ако автоматичното довършване „същата група“ и „интегриране на телефонен номер“ са активирани, съвпадението в едното е достатъчно, за да се покаже на потребителя.",
    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Разрешаване на автоматично довършване при въвеждане на пълното име или имейл адрес (като игнорирате липсващото съвпадение в телефонния указател и сте в същата група)",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Показване на текст за отказ от отговорност на страницата за качване на публична връзка (показва се само когато списъкът с файлове е скрит)",
    "This text will be shown on the public link upload page when the file list is hidden." : "Този текст ще се показва на страницата за качване на публична връзка, когато списъкът с файлове е скрит.",
    "Default share permissions" : "Права за споделяне по подразбиране",
    "Reasons to use Nextcloud in your organization" : "Причини да използвате Nextcloud във вашата организация",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Разработен от {communityopen}общността на Nextcloud{linkclose}, {githubopen}изходният код{linkclose} е лицензиран под {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Харесайте страницата ни във Facebook",
    "Follow us on Twitter" : "Следвайте ни в Twitter",
    "Follow us on Mastodon" : "Следвайте ни в Mastodon",
    "Check out our blog" : "Посетете блога ни",
    "Subscribe to our newsletter" : "Абонирайте се за нашия имейл бюлетин",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Тази общностна версия на Nextcloud не се поддържа и не са налични незабавни известия.",
    "Use a second factor besides your password to increase security for your account." : "Ползвайте двустепенно удостоверяване за да повишите сигурността на профила си.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Ако използвате приложения на трети страни, за да се свържете с Nextcloud, моля, не забравяйте да създадете и конфигурирате парола за приложение за всяко едно от тях, преди да активирате удостоверяване на втория фактор.",
    "You created app password \"{token}\"" : "Създадохте парола за приложение „{token}“",
    "An administrator created app password \"{token}\"" : "Администратор създаде парола за приложение „{token}“",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "За да стартирате това, имате нужда от разширението PHP POSIX. Вижте {linkstart}документацията на PHP{linkend} за повече подробности.",
    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Използвайте системна услуга cron, за да извиквате файла cron.php на всеки 5 минути. Препоръчва се за всички екземпляри.",
    "Choose profile picture from files" : "Избор на профилна снимка от файлове",
    "png or jpg, max. 20 MB" : "png или jpg, макс. 20 MB",
    "Your location" : "Вашето местоположение",
    "Edit User" : "Редактиране на потребител",
    "Will be autogenerated" : "Ще се генерира автоматично",
    "Add a new user" : "Добавяне на новия потребител",
    "No users in here" : "Тук няма потребители",
    "Default quota:" : "Стандартна квота:",
    "Show Languages" : "Показвай ползвания език",
    "Send email to new user" : "Изпращай писмо към нов потребител",
    "Plain" : "Обикновен",
    "NT LAN Manager" : "NT LAN Manager",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Authentication method" : "Метод за удостоверяване",
    "Allow username autocompletion in share dialog" : "Разрешаване на автоматично довършване на име на потребител в диалоговия прозорец за споделяне",
    "Allow username autocompletion to users within the same groups" : "Разрешаване на автоматично довършване на име на потребител на потребители в същите групи"
},
"nplurals=2; plural=(n != 1);");
